==> colby-0.1.2.tgz: package/README.md <==
# Colby


[![npm version][npm-version-src]][npm-version-href]
[![npm href][standard-js-src]][standard-js-href]

<!-- Refs -->
[standard-js-src]: https://img.shields.io/badge/license-MIT-brightgreen?&style=flat-square
[standard-js-href]: https://github.com/Generalsimus/colby/blob/master/LICENSE

[npm-version-src]: https://img.shields.io/npm/v/colby?&style=flat-square
[npm-version-href]: https://www.npmjs.com/package/colby


### RGB Color
```js
const { toRgb } = require("colby");

console.log(toRgb(200, 1, 1)("This text is rgb(200, 1, 1) red!"));


const blueColor = toRgb(0, 0, 255);

console.log(blueColor("This text is rgb(0, 0, 255) blue!"));
```

### Default Colors
```js
const { colors } = require("colby");

console.log(colors.Red("This text is red"));
console.log(colors.Green("This text is green"));
console.log(colors.Cyan("This text is cyan"));
console.log(colors.Yellow("This text is yellow"));

// text Background-color
console.log(colors.Red("Background of this text is red", true));
console.log(colors.Green("Background of this text is green", true));
console.log(colors.Cyan("Background of this text is cyan", true));
console.log(colors.Yellow("Background of this text is yellow", true));
```

### Style
```js
const { style } = require("colby");

console.log(style.Underlined("text with underline"));
console.log(style.Dim("Text with dim"));
console.log(style.Italic("Text with italic"));
console.log(style.Reverse("Text with reverse"));
console.log(style.StrikeThrough("Text with strike through"));

```



## License

MIT

==> colby-0.1.3.tgz: package/README.md <==
# Colby

[![npm version][npm-version-src]][npm-version-href]
[![npm href][standard-js-src]][standard-js-href]

<!-- Refs -->

[standard-js-src]: https://img.shields.io/badge/license-MIT-brightgreen?&style=flat-square
[standard-js-href]: https://github.com/Generalsimus/colby/blob/master/LICENSE
[npm-version-src]: https://img.shields.io/npm/v/colby?&style=flat-square
[npm-version-href]: https://www.npmjs.com/package/colby

### RGB Color

```js
const { toRgb } = require("colby");

console.log(toRgb(200, 1, 1)("This text is rgb(200, 1, 1) red!"));

const blueColor = toRgb(0, 0, 255);

console.log(blueColor("Background of this text is rgb(0, 0, 255) blue!", true));
```
![1](https://user-images.githubusercontent.com/33871030/211204025-c2e3ee05-7ec7-45e9-81b7-0f8209d45d97.png)

### HEX Color

```js
const { toHex } = require("colby");

console.log(toHex("#FF0000")("This text is #FF0000 red!"));

const blueColor = toHex("#0000FF");

console.log(blueColor("Background of this text is #0000FF blue!", true));
```
![2](https://user-images.githubusercontent.com/33871030/211204037-109c0049-d468-42fd-8701-60e50e78708a.png)

### Default Colors

```js
const { colors } = require("colby");

console.log(colors.Red("This text is red"));
console.log(colors.Green("This text is green"));
console.log(colors.Cyan("This text is cyan"));
console.log(colors.Yellow("This text is yellow"));

// text Background-color
console.log(colors.Red("Background of this text is red", true));
console.log(colors.Green("Background of this text is green", true));
console.log(colors.Cyan("Background of this text is cyan", true));
console.log(colors.Yellow("Background of this text is yellow", true));
```
![3](https://user-images.githubusercontent.com/33871030/211204045-721e48f5-05e2-4d09-9cb6-ec8f7db4563b.png)

### Style

```js
const { style } = require("colby");

console.log(style.Underlined("text with underline"));
console.log(style.Dim("Text with dim"));
console.log(style.Italic("Text with italic"));
console.log(style.Reverse("Text with reverse"));
console.log(style.StrikeThrough("Text with strike through"));
```
![4](https://user-images.githubusercontent.com/33871030/211204050-f51554ad-5945-46af-85e0-637c43bafbc2.png)

## License

MIT
